@@ -252,9 +252,19 @@ def version_sync():
     with db_client.context():
         version =  {
                                
-                                'setting'  :[
-                                            
-                                        ]
+                                'setting':[
+                                            {
+                                                "table_name": "setting",
+                                                "version" : 2,
+                                                "script": "ALTER TABLE setting ADD COLUMN device_id TEXT",
+                                            },
+                                            {
+                                                "table_name": "setting",
+                                                "version" : 3,
+                                                "script": "ALTER TABLE setting ADD COLUMN membership_configurations TEXT",
+                                            }
+                                               
+                                        ],
                                        
                             }
                                 
