@@ -11,7 +11,7 @@ import logging
 from datetime import datetime
 
 logger = logging.getLogger('decorator')
-
+#logger = logging.getLogger('debug')
 
 def auth_token_required(f):
     @wraps(f)
@@ -26,6 +26,7 @@ def auth_token_required(f):
             try:
                 auth_details_json = decrypt_json(auth_token)
             except:
+                logger.error('Authenticated token is not valid')
                 return ("Authenticated token is not valid", 401)
             
             logger.debug('auth_details_json=%s', auth_details_json)
